[![Python: 3.10, 3.11](https://img.shields.io/badge/Python-3.10%2C%203.11-blue.svg)](https://www.python.org/)
[![Systems: Windows, Mac, Linux](https://img.shields.io/badge/Systems-Windows%2C%20Mac%2C%20Linux-blue.svg)]()
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![Code style: black](https://img.shields.io/badge/Style-Black%2C%20PEP--8-blue.svg)](https://github.com/psf/black)

[![Unit Tests](https://github.com/B-Roux/momlib/actions/workflows/tests.yml/badge.svg?branch=master)](https://github.com/B-Roux/momlib/actions/workflows/tests.yml)

# Mathematical Object Manipulation Library

This package attempts to capture a limited set of advanced mathematical objects and their associated operations in the most basic and natural data types and structures available in standard Python 3, and while having no requirements other than the Python standard library.

At the moment, this package is being developed by me for my own purposes, but I hope that enough people find it useful enough that that stops being the case. Thank you for using and supporting my project!

Please note that this package is currently in version 0.0.x meaning very early development. The public API may change drastically and often. As soon as version 0.1.0 is released, you should in most cases be able to expect some consistency. I hope this comes soon!

# Installing

This package can be installed from the PyPI release:

```sh
python -m pip install momlib
```

# Documentation
I'm working on it! For now, feel free to browse the "docs" directory

# Licensing
The official (and only!) licensing agreement for using this project can be found in [the licensing file](./LICENSE.md). It's pretty simple: you can privately or commercially modify, distribute or use this software - for free (gratis *and* libre) - under the exact terms detailed by this license. Be aware that I am not liable for any use of this software, nor do I provide it with any warrantees or guarantees.
